fullCountryCode property
String
get
fullCountryCode
Returns the full country code combining dial code and region code
Implementation
String get fullCountryCode {
return dialCode + regionCode;
}
Returns the full country code combining dial code and region code
String get fullCountryCode {
return dialCode + regionCode;
}