CustomPhoneInput class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CustomPhoneInput
Constructors
-
CustomPhoneInput({Key? key, String initialCountry = 'EG', String languageCode = 'en', List<
String> availableCountries = const [], void onCountryChanged(Country country)?, void onPhoneNumberChanged(String phoneNumber)?, String? initialValue, bool enabled = true, bool readOnly = false, InputDecoration? decoration, TextStyle? style, String? validator(String?)?, TextEditingController? controller}) -
const
Properties
-
availableCountries
→ List<
String> -
List of country codes that should be available for selection
final
- controller → TextEditingController?
-
final
- decoration → InputDecoration?
-
The decoration for the input field
final
- enabled → bool
-
Whether the field is enabled
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialCountry → String
-
The initial country code to display
final
- initialValue → String?
-
Initial phone number value
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- languageCode → String
-
Language code for localization
final
- onCountryChanged → void Function(Country country)?
-
Callback when country is changed
final
- onPhoneNumberChanged → void Function(String phoneNumber)?
-
Callback when phone number is changed
final
- readOnly → bool
-
Whether the field is read-only
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → TextStyle?
-
The style for the input text
final
- validator → String? Function(String?)?
-
The validator callback for the input field
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CustomPhoneInput> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited